@@ -71,8 +71,8 @@ class Tredis(threading.Thread):
                     data = message['data']
                     logger.info(f'redis_working_thread got msg: {data}')
 
-                    if data == self.str_thread_exit_magic:
-                        if data.split(' ')[1] == str(self):
+                    if isinstance(data, str) and data.startswith(self.str_thread_exit_magic):
+                        if data[len(self.str_thread_exit_magic)+1:] == str(self):
                             logger.info(f'{self} to exit')
                             break
                     else:
